import { Store } from "antd/es/form/interface";
import { useEffect, useRef } from "react";
import videojs from "video.js";
import "video.js/dist/video-js.css";

const Videos = (props: Store) => {
  const { onReady } = props;
  let videoRef = useRef<HTMLDivElement>(null);
  let playerRef = useRef<any>(null); // 使用 any 类型
  const videoJsOptions = {
    autoplay: true,
    controls: true,
    responsive: true,
    fluid: true,
    sources: [
      {
        src: "",
        type: "application/x-mpegURL",
      },
    ],
  };
  useEffect(() => {
    if (!props.url) return;
    videoJsOptions.sources[0].src = props.url;
    if (!playerRef.current && videoRef.current) {
      const videoElement = document.createElement(`video-js`);
      videoElement.classList.add(`vjs-big-play-centered${props.url}`);
      videoRef.current.appendChild(videoElement);
      const player = (playerRef.current = videojs(
        videoElement,
        videoJsOptions,
        () => {
          videojs.log("player is ready");
          onReady && onReady(player);
        }
      ));
    } else {
      const player = playerRef.current;
      player?.autoplay(videoJsOptions?.autoplay);
      player.src(videoJsOptions?.sources);
    }
    return () => {
      if (playerRef.current) {
        playerRef.current.dispose();
        playerRef.current = null;
      }
    };
  }, [videoRef, onReady, props.url]);

  return (
    <>
      <div data-vjs-player style={{ width: "100%", height: "100%" }}>
        <div ref={videoRef} style={{ width: "100%", height: "100%" }} />
      </div>
    </>
  );
};

export default Videos;
