import { Button, Space, Modal, FormInstance } from "antd";
import { inject, observer } from "mobx-react";
import BTable from "@/components/b_table";
import { useEffect, useState } from "react";
import { Store } from "antd/lib/form/interface";
import SimpleForm from "@/components/form/simple_form";
import React from "react";
import { columns, defaultCatConfig } from "./levcat_column";

const LeaveCat = (props: Store) => {
  const { leaveCategoryStore } = props;
  const [isModalOpen, setIsModalOpen] = useState<boolean>(false);
  const [projectConfig, setProjectConfig] = useState<any>([]);
  const formRef = React.useRef<FormInstance>(null);
  const [record, setRecord] = useState<any>(null);
  useEffect(() => {
    leaveCategoryStore.getlist();
    setProjectConfig(defaultCatConfig);
  }, [leaveCategoryStore]);
  const column_widget = (any, record) => {
    return (
      <Space wrap>
        <Button
          type="dashed"
          size="small"
          onClick={() => {
            edit(record);
          }}
        >
          编辑
        </Button>

        <Button
          type="dashed"
          danger
          size="small"
          onClick={() => {
            leaveCategoryStore.deleteItem(record.id);
          }}
        >
          删除
        </Button>
      </Space>
    );
  };
  const edit = (record) => {
    setIsModalOpen(true);
    setRecord(record);
  };
  const onFinish = (values: any) => {
    let data = {
      ...values,
      pid: values.pid ?? 0,
    };
    if (!record?.id) {
      leaveCategoryStore.add(data);
    } else {
      leaveCategoryStore.putItem(record.id, data);
    }
    setIsModalOpen(false);
  };

  const onFinishFailed = () => {};
  return (
    <div className="contentBox">
      <Space direction="vertical" size="middle" style={{ display: "flex" }}>
        <Space direction="horizontal" size={"middle"}>
          <Button
            type="default"
            onClick={() => {
              setRecord(null);
              setProjectConfig(defaultCatConfig);
              setIsModalOpen(true);
            }}
          >
            添加请期分类
          </Button>
        </Space>
        <BTable
          store={leaveCategoryStore}
          columns={[
            ...columns,
            {
              title: "操作",
              dataIndex: "id",
              ellipsis: {
                showTitle: false,
              },
              render: (any, record) => column_widget(any, record),
            },
          ]}
          dataSource={leaveCategoryStore.list}
        />
        <Modal
          title={!record?.id ? "添加分类" : "编辑分类"}
          width={500}
          open={isModalOpen}
          afterClose={() => formRef.current?.resetFields()}
          onOk={() => formRef.current?.submit()}
          okText="确定"
          cancelText="取消"
          onCancel={() => {
            setIsModalOpen(false);
          }}
        >
          <SimpleForm
            formRef={formRef}
            createCallback={() => {
              if (record?.id) {
                formRef.current?.setFieldsValue(record);
              } else {
                formRef.current?.setFieldsValue(null);
              }
            }}
            formName="card_basic"
            colProps={25}
            subBtnName="提交"
            formDatas={projectConfig}
            onFinish={onFinish}
            initialValues={true}
            onFinishFailed={onFinishFailed}
          />
        </Modal>
      </Space>
    </div>
  );
};

export default inject("leaveCategoryStore")(observer(LeaveCat));
